"""
# @Project sphinxcontrib-analytics
# @File    analytics.py
# @Author  MT308
# @Date    2024/9/1 23:44
"""
from sphinx.application import Sphinx
from sphinx.util import logging
from sphinx.errors import ExtensionError

from sphinxcontrib_analytics_hub.const import GOOGLE_GTAG, GOOGLE_SCRIPT, BAIDU_SCRIPT

ANALYTICS_WITH = ["google", "baidu"]

_logger = logging.getLogger(__name__)


def add_analytics_javascript(app: Sphinx, pagename, templatename, context, doctree):
    if not app.config.analytics_enabled:
        _logger.info("Skipping analytics javascript generation at %s" % pagename)
        return
    metatags = context.get('metatags', '')
    if app.config.analytics_with == 'google':
        metatags += GOOGLE_GTAG % app.config.analytics_id
        metatags += GOOGLE_SCRIPT % app.config.analytics_id
    else:
        metatags += BAIDU_SCRIPT % app.config.analytics_id

    context['metatags'] = metatags


def check_config(app: Sphinx):
    if not app.config.analytics_id:
        raise ExtensionError(
            "'analytics_id' config value must be set for google or baidu statistics to function properly.")
    if not app.config.analytics_with in ANALYTICS_WITH:
        raise ExtensionError(
            "'analytics_id' config value must be one of 'google' or 'baidu'")



"""
# @Project sphinxcontrib-analytics
# @File    const.py
# @Author  MT308
# @Date    2024/9/2 1:05
"""
GOOGLE_GTAG = """
<!-- Google tag (gtag.js) -->
<script async src="https://www.googletagmanager.com/gtag/js?id=%s"></script>
"""

GOOGLE_SCRIPT = """
<script>
    window.dataLayer = window.dataLayer || [];
    function gtag(){dataLayer.push(arguments);}
    gtag('js', new Date());
    gtag('config', '%s');
</script>
"""

BAIDU_SCRIPT = """
<script>
var _hmt = _hmt || [];
(function() {
  var hm = document.createElement("script");
  hm.src = "https://hm.baidu.com/hm.js?%s";
  var s = document.getElementsByTagName("script")[0]; 
  s.parentNode.insertBefore(hm, s);
})();
</script>
"""



from sphinx.application import Sphinx
from sphinx.util.typing import ExtensionMetadata

from sphinxcontrib_analytics_hub import __version__
from sphinxcontrib_analytics_hub.analytics import add_analytics_javascript, check_config


def setup(app: Sphinx) -> ExtensionMetadata:
    # config for analytics
    app.add_config_value('analytics_enabled', True, 'html')
    app.add_config_value('analytics_with', 'google', 'html')
    app.add_config_value('analytics_id', '', 'html')

    # hooks for analytics
    app.connect('builder-inited', check_config)
    app.connect('html-page-context', add_analytics_javascript)

    return {
        'parallel_read_safe': True,
        'parallel_write_safe': True,
        'version': __version__,
    }